@@ -52,6 +52,21 @@ const theme = createTheme(
         palette: {
             background: {},
         },
+        shape:{
+            borderRadius:12,
+        },
+        overrides: {
+            MuiButton: {
+                root: {
+                    textTransform: "none",
+                },
+            },
+            MuiTab: {
+                root: {
+                    textTransform: "none",
+                },
+            },
+        },
     },
     zhCN
 );
