@@ -3,23 +3,24 @@ import { connect } from "react-redux";
 import API from "../../middleware/Api";
 
 import {
-    withStyles,
-    Paper,
     Avatar,
-    Typography,
-    Tabs,
+    Grid,
+    Paper,
     Tab,
     Table,
     TableBody,
     TableCell,
     TableHead,
     TableRow,
-    Grid,
+    Tabs,
+    Typography,
+    withStyles,
 } from "@material-ui/core";
 import { withRouter } from "react-router";
 import Pagination from "@material-ui/lab/Pagination";
 import { formatLocalTime } from "../../utils/datetime";
 import { toggleSnackbar } from "../../redux/explorer";
+import { withTranslation } from "react-i18next";
 
 const styles = (theme) => ({
     layout: {
@@ -35,6 +36,7 @@ const styles = (theme) => ({
         },
     },
     userNav: {
+        borderRadius: `${theme.shape.borderRadius}px ${theme.shape.borderRadius}px 0 0`,
         height: "270px",
         backgroundColor: theme.palette.primary.main,
         padding: "20px 20px 2em",
@@ -190,13 +192,13 @@ class ProfileCompoment extends Component {
     };
 
     render() {
-        const { classes } = this.props;
+        const { classes, t } = this.props;
 
         return (
             <div className={classes.layout}>
                 {this.state.user === null && <div></div>}
                 {this.state.user !== null && (
-                    <Paper square>
+                    <Paper>
                         <div className={classes.userNav}>
                             <div>
                                 <Avatar
@@ -221,9 +223,9 @@ class ProfileCompoment extends Component {
                             onChange={this.handleChange}
                             centered
                         >
-                            <Tab label="全部分享" />
-                            <Tab label="热门分享" />
-                            <Tab label="个人资料" />
+                            <Tab label={t("setting.allShares")} />
+                            <Tab label={t("setting.trendingShares")} />
+                            <Tab label={t("setting.profile")} />
                         </Tabs>
                         {this.state.listType === 2 && (
                             <div className={classes.infoContainer}>
@@ -238,7 +240,7 @@ class ProfileCompoment extends Component {
                                             color="textSecondary"
                                             variant="h6"
                                         >
-                                            UID
+                                            {t("setting.uid")}
                                         </Typography>
                                         <Typography>
                                             {this.state.user.id}
@@ -254,7 +256,7 @@ class ProfileCompoment extends Component {
                                             color="textSecondary"
                                             variant="h6"
                                         >
-                                            昵称
+                                            {t("setting.nickname")}
                                         </Typography>
                                         <Typography>
                                             {this.state.user.nick}
@@ -270,7 +272,7 @@ class ProfileCompoment extends Component {
                                             color="textSecondary"
                                             variant="h6"
                                         >
-                                            用户组
+                                            {t("setting.group")}
                                         </Typography>
                                         <Typography>
                                             {this.state.user.group}
@@ -286,7 +288,7 @@ class ProfileCompoment extends Component {
                                             color="textSecondary"
                                             variant="h6"
                                         >
-                                            分享总数
+                                            {t("setting.totalShares")}
                                         </Typography>
                                         <Typography>
                                             {this.state.total}
@@ -302,7 +304,7 @@ class ProfileCompoment extends Component {
                                             color="textSecondary"
                                             variant="h6"
                                         >
-                                            注册日期
+                                            {t("setting.regTime")}
                                         </Typography>
                                         <Typography>
                                             {this.state.user.date}
@@ -318,13 +320,15 @@ class ProfileCompoment extends Component {
                                     <Table className={classes.table}>
                                         <TableHead>
                                             <TableRow>
-                                                <TableCell>文件名</TableCell>
+                                                <TableCell>
+                                                    {t("setting.fileName")}
+                                                </TableCell>
                                                 <TableCell
                                                     className={
                                                         classes.mobileHide
                                                     }
                                                 >
-                                                    分享日期
+                                                    {t("setting.shareDate")}
                                                 </TableCell>
                                                 <TableCell
                                                     className={[
@@ -332,7 +336,9 @@ class ProfileCompoment extends Component {
                                                         classes.mobileHide,
                                                     ]}
                                                 >
-                                                    下载次数
+                                                    {t(
+                                                        "setting.downloadNumber"
+                                                    )}
                                                 </TableCell>
                                                 <TableCell
                                                     className={[
@@ -340,7 +346,7 @@ class ProfileCompoment extends Component {
                                                         classes.mobileHide,
                                                     ]}
                                                 >
-                                                    浏览次数
+                                                    {t("setting.viewNumber")}
                                                 </TableCell>
                                             </TableRow>
                                         </TableHead>
@@ -363,7 +369,11 @@ class ProfileCompoment extends Component {
                                                                 {row.source
                                                                     ? row.source
                                                                           .name
-                                                                    : "[已失效]"}
+                                                                    : "[" +
+                                                                      t(
+                                                                          "share.expired"
+                                                                      ) +
+                                                                      "]"}
                                                             </Typography>
                                                         </TableCell>
                                                         <TableCell
@@ -373,8 +383,7 @@ class ProfileCompoment extends Component {
                                                             }
                                                         >
                                                             {formatLocalTime(
-                                                                row.create_date,
-                                                                "YYYY-MM-DD H:mm:ss"
+                                                                row.create_date
                                                             )}
                                                         </TableCell>
                                                         <TableCell
@@ -429,6 +438,6 @@ class ProfileCompoment extends Component {
 const Profile = connect(
     mapStateToProps,
     mapDispatchToProps
-)(withStyles(styles)(withRouter(ProfileCompoment)));
+)(withStyles(styles)(withRouter(withTranslation()(ProfileCompoment))));
 
 export default Profile;
