@@ -9,7 +9,7 @@ export const imgPreviewSuffix = [
     "svg",
     "webp",
 ];
-export const msDocPreviewSuffix = [
+export let msDocPreviewSuffix = [
     "ppt",
     "pptx",
     "pps",
@@ -148,3 +148,7 @@ export const getTaskProgress = (type: any, status: any) => {
     }
     return i18next.t(taskProgress[status]);
 };
+
+export const setWopiExts = (exts: string[]) => {
+    msDocPreviewSuffix = exts;
+};
\ No newline at end of file
