@@ -8,13 +8,15 @@ import ChainedBackend, { ChainedBackendOptions } from "i18next-chained-backend";
 import LanguageDetector from "i18next-browser-languagedetector";
 import LocalStorageBackend from "i18next-localstorage-backend";
 
+declare let ASSETS_VERSION: string;
+
 // eslint-disable-next-line @typescript-eslint/ban-ts-ignore
 // @ts-ignore
 i18n.use(ChainedBackend)
     .use(LanguageDetector)
     .use(initReactI18next)
     .init({
-        fallbackLng: "zh-CN",
+        fallbackLng: "en-US",
         debug: true,
         ns: ["common", "application"],
         load: "currentOnly",
@@ -23,12 +25,16 @@ i18n.use(ChainedBackend)
             escapeValue: false,
         },
         backend: {
-            backends: [LocalStorageBackend, Backend],
+            backends:
+                process.env.NODE_ENV === "development"
+                    ? [Backend]
+                    : [LocalStorageBackend, Backend],
             backendOptions: [
                 {
                     expirationTime: 7 * 24 * 60 * 60 * 1000, // 7 days
                 },
                 {
+                    queryStringParams: { v: ASSETS_VERSION },
                     loadPath: "/locales/{{lng}}/{{ns}}.json",
                 },
             ],
@@ -48,6 +54,10 @@ export const languages = [
         code: "zh-CN",
         displayName: "简体中文",
     },
+    {
+        code: "zh-TW",
+        displayName: "繁體中文",
+    },
 ];
 
 export default i18n;
