@@ -4,59 +4,38 @@ import cloudreveApp, { initState as cloudreveState } from "./index";
 import { initState as viewUpdateState } from "../redux/viewUpdate/reducer";
 import { initState as explorerState } from "../redux/explorer/reducer";
 
-import {
-    setModalsLoading,
-    openLoadingDialog,
-    openGetSourceDialog,
-    openShareDialog,
-    openMoveDialog,
-    navigateUp,
-    navigateTo,
-    drawerToggleAction,
-    changeViewMethod,
-    changeContextMenu,
-    dragAndDrop,
-    setNavigatorLoadingStatus,
-    setNavigatorError,
-    addSelectedTargets,
-    setNavigator,
-    setSelectedTarget,
-    removeSelectedTargets,
-    toggleDaylightMode,
-    applyThemes,
-    openCreateFolderDialog,
-    openRenameDialog,
-    openRemoveDialog,
-    openResaveDialog,
-    setUserPopover,
-    setShareUserPopover,
-    setSiteConfig,
-    openMusicDialog,
-    openRemoteDownloadDialog,
-    openTorrentDownloadDialog,
-    openDecompressDialog,
-    openCompressDialog,
-    openCopyDialog,
-    closeAllModals,
-    toggleSnackbar,
-    setSessionStatus,
-    enableLoadUploader,
-    refreshFileList,
-    searchMyFile,
-    showImgPreivew,
-    refreshStorage,
-    saveFile,
-    setLastSelect,
-    setShiftSelectedIds,
-} from "../actions/index";
 import { changeSubTitle, setSubtitle } from "../redux/viewUpdate/action";
 import {
-    updateFileList,
-    setFileList,
-    setDirList,
-    setSortMethod,
+    addSelectedTargets,
     changeSortMethod,
+    removeSelectedTargets,
+    setDirList,
+    setFileList,
+    setLastSelect,
+    setSelectedTarget,
+    setShiftSelectedIds,
+    setSortMethod,
+    updateFileList,
 } from "../redux/explorer/action";
+import {
+    applyThemes, changeContextMenu, changeViewMethod,
+    closeAllModals, dragAndDrop, drawerToggleAction, navigateTo, navigateUp,
+    openCompressDialog,
+    openCopyDialog, openCreateFolderDialog,
+    openDecompressDialog,
+    openGetSourceDialog,
+    openLoadingDialog, openMoveDialog, openMusicDialog,
+    openRemoteDownloadDialog, openRemoveDialog, openRenameDialog, openResaveDialog, openShareDialog,
+    openTorrentDownloadDialog,
+    refreshFileList,
+    refreshStorage,
+    saveFile,
+    searchMyFile,
+    setModalsLoading, setNavigator, setNavigatorError, setNavigatorLoadingStatus, setSessionStatus, setShareUserPopover,
+    setSiteConfig, setUserPopover,
+    showImgPreivew, toggleDaylightMode,
+    toggleSnackbar
+} from "../redux/explorer";
 
 const initState = {
     ...cloudreveState,
@@ -1116,17 +1095,6 @@ describe("index reducer", () => {
         });
     });
 
-    it("should handle ENABLE_LOAD_UPLOADER", () => {
-        const action = enableLoadUploader();
-        expect(cloudreveApp(initState, action)).toEqual({
-            ...initState,
-            viewUpdate: {
-                ...initState.viewUpdate,
-                loadUploader: true,
-            },
-        });
-    });
-
     it("should handle REFRESH_FILE_LIST", () => {
         const action = refreshFileList();
         expect(cloudreveApp(initState, action)).toEqual({
