@@ -1,5 +1,3 @@
-import { getResumeCtx } from "../component/Uploader/core/utils";
-
 export const sizeToString = (bytes) => {
     if (bytes === 0 || bytes === "0") return "0 B";
     const k = 1024;
@@ -157,10 +155,9 @@ export function vhCheck() {
 }
 
 export const removeI18nCache = () => {
-    for (let i = 0, len = localStorage.length; i < len; i++) {
-        const key = localStorage.key(i);
+    Object.keys(localStorage).forEach(function (key) {
         if (key && key.startsWith("i18next_res_")) {
             localStorage.removeItem(key);
         }
-    }
+    });
 };
