@@ -25,7 +25,7 @@ func UseSlaveAria2Instance(clusterController cluster.Controller) gin.HandlerFunc
 			// 获取对应主机节点的从机Aria2实例
 			caller, err := clusterController.GetAria2Instance(siteID.(string))
 			if err != nil {
-				c.JSON(200, serializer.Err(serializer.CodeNotSet, "无法获取 Aria2 实例", err))
+				c.JSON(200, serializer.Err(serializer.CodeNotSet, "Failed to get Aria2 instance", err))
 				c.Abort()
 				return
 			}
@@ -35,7 +35,7 @@ func UseSlaveAria2Instance(clusterController cluster.Controller) gin.HandlerFunc
 			return
 		}
 
-		c.JSON(200, serializer.ParamErr("未知的主机节点ID", nil))
+		c.JSON(200, serializer.ParamErr("Unknown master node ID", nil))
 		c.Abort()
 	}
 }
@@ -44,14 +44,14 @@ func SlaveRPCSignRequired(nodePool cluster.Pool) gin.HandlerFunc {
 	return func(c *gin.Context) {
 		nodeID, err := strconv.ParseUint(c.GetHeader(auth.CrHeaderPrefix+"Node-Id"), 10, 64)
 		if err != nil {
-			c.JSON(200, serializer.ParamErr("未知的主机节点ID", err))
+			c.JSON(200, serializer.ParamErr("Unknown master node ID", err))
 			c.Abort()
 			return
 		}
 
 		slaveNode := nodePool.GetNodeByID(uint(nodeID))
 		if slaveNode == nil {
-			c.JSON(200, serializer.ParamErr("未知的主机节点ID", err))
+			c.JSON(200, serializer.ParamErr("Unknown master node ID", err))
 			c.Abort()
 			return
 		}
