@@ -38,7 +38,7 @@ func GetPublicKey(r *http.Request) ([]byte, error) {
 	// 确保这个 public key 是由 OSS 颁发的
 	if !strings.HasPrefix(string(pubURL), "http://gosspublic.alicdn.com/") &&
 		!strings.HasPrefix(string(pubURL), "https://gosspublic.alicdn.com/") {
-		return pubKey, errors.New("公钥URL无效")
+		return pubKey, errors.New("public key url invalid")
 	}
 
 	// 获取公钥
