@@ -15,6 +15,8 @@ const (
 	TransferTaskType
 	// ImportTaskType 导入任务
 	ImportTaskType
+	// RecycleTaskType 回收任务
+	RecycleTaskType
 )
 
 // 任务状态
@@ -87,12 +89,12 @@ func Resume(p Pool) {
 	if len(tasks) == 0 {
 		return
 	}
-	util.Log().Info("从数据库中恢复 %d 个未完成任务", len(tasks))
+	util.Log().Info("Resume %d unfinished task(s) from database.", len(tasks))
 
 	for i := 0; i < len(tasks); i++ {
 		job, err := GetJobFromModel(&tasks[i])
 		if err != nil {
-			util.Log().Warning("无法恢复任务，%s", err)
+			util.Log().Warning("Failed to resume task: %s", err)
 			continue
 		}
 
@@ -113,6 +115,8 @@ func GetJobFromModel(task *model.Task) (Job, error) {
 		return NewTransferTaskFromModel(task)
 	case ImportTaskType:
 		return NewImportTaskFromModel(task)
+	case RecycleTaskType:
+		return NewRecycleTaskFromModel(task)
 	default:
 		return nil, ErrUnknownTaskType
 	}
